aboutsummaryrefslogtreecommitdiff
path: root/lib/csapi/to_device.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/csapi/to_device.h')
-rw-r--r--lib/csapi/to_device.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/lib/csapi/to_device.h b/lib/csapi/to_device.h
index f5d69d65..54828337 100644
--- a/lib/csapi/to_device.h
+++ b/lib/csapi/to_device.h
@@ -13,7 +13,7 @@ namespace Quotient {
* This endpoint is used to send send-to-device events to a set of
* client devices.
*/
-class SendToDeviceJob : public BaseJob {
+class QUOTIENT_API SendToDeviceJob : public BaseJob {
public:
/*! \brief Send an event to a given set of devices.
*
@@ -21,9 +21,10 @@ public:
* The type of event to send.
*
* \param txnId
* The transaction ID for this event. Clients should generate an
* ID unique across requests with the same access token; it will be
* used by the server to ensure idempotency of requests.
*
* \param messages
* The messages to send. A map from user ID, to a map from
@@ -32,7 +33,7 @@ public:
*/
explicit SendToDeviceJob(
const QString& eventType, const QString& txnId,
- const QHash<QString, QHash<QString, QJsonObject>>& messages = {});
+ const QHash<QString, QHash<QString, QJsonObject>>& messages);
};
} // namespace Quotient
@@ -21,9 +21,10 @@ public:
*
* \param txnId
- * The transaction ID for this event. Clients should generate an
- * ID unique across requests with the same access token; it will be
- * used by the server to ensure idempotency of requests.
+ * The [transaction ID](/client-server-api/#transaction-identifiers) for
+ * this event. Clients should generate an ID unique across requests with the
+ * same access token; it will be used by the server to ensure idempotency of
+ * requests.
*
* \param messages